==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/ScaleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.ScaleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Container App scaling configurations.
 * @property maxReplicas Optional. Maximum number of container replicas. Defaults to 10 if not set.
 * @property minReplicas Optional. Minimum number of container replicas.
 * @property rules Scaling rules.
 */
public data class ScaleArgs(
    public val maxReplicas: Output<Int>? = null,
    public val minReplicas: Output<Int>? = null,
    public val rules: Output<List<ScaleRuleArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.ScaleArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.ScaleArgs =
        com.pulumi.azurenative.app.inputs.ScaleArgs.builder()
            .maxReplicas(maxReplicas?.applyValue({ args0 -> args0 }))
            .minReplicas(minReplicas?.applyValue({ args0 -> args0 }))
            .rules(
                rules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ScaleArgs].
 */
@PulumiTagMarker
public class ScaleArgsBuilder internal constructor() {
    private var maxReplicas: Output<Int>? = null

    private var minReplicas: Output<Int>? = null

    private var rules: Output<List<ScaleRuleArgs>>? = null

    /**
     * @param value Optional. Maximum number of container replicas. Defaults to 10 if not set.
     */
    @JvmName("wrjptwbtyfrtlivn")
    public suspend fun maxReplicas(`value`: Output<Int>) {
        this.maxReplicas = value
    }

    /**
     * @param value Optional. Minimum number of container replicas.
     */
    @JvmName("mqiewvhpiskxirtj")
    public suspend fun minReplicas(`value`: Output<Int>) {
        this.minReplicas = value
    }

    /**
     * @param value Scaling rules.
     */
    @JvmName("wstjcbsapngpwnel")
    public suspend fun rules(`value`: Output<List<ScaleRuleArgs>>) {
        this.rules = value
    }

    @JvmName("gowimnkigcjdgbkh")
    public suspend fun rules(vararg values: Output<ScaleRuleArgs>) {
        this.rules = Output.all(values.asList())
    }

    /**
     * @param values Scaling rules.
     */
    @JvmName("eugjpydxpmndoifu")
    public suspend fun rules(values: List<Output<ScaleRuleArgs>>) {
        this.rules = Output.all(values)
    }

    /**
     * @param value Optional. Maximum number of container replicas. Defaults to 10 if not set.
     */
    @JvmName("ahgfppxqyajhvasv")
    public suspend fun maxReplicas(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxReplicas = mapped
    }

    /**
     * @param value Optional. Minimum number of container replicas.
     */
    @JvmName("wkcqwwtsufqvrbiw")
    public suspend fun minReplicas(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minReplicas = mapped
    }

    /**
     * @param value Scaling rules.
     */
    @JvmName("wjyvlmpfvjpcault")
    public suspend fun rules(`value`: List<ScaleRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    /**
     * @param argument Scaling rules.
     */
    @JvmName("moroiwnchogvemdl")
    public suspend fun rules(argument: List<suspend ScaleRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ScaleRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument Scaling rules.
     */
    @JvmName("ktxhxuduyixsywyu")
    public suspend fun rules(vararg argument: suspend ScaleRuleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ScaleRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument Scaling rules.
     */
    @JvmName("iibbuachqvnexvck")
    public suspend fun rules(argument: suspend ScaleRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ScaleRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param values Scaling rules.
     */
    @JvmName("abvdyxatvldnphej")
    public suspend fun rules(vararg values: ScaleRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    internal fun build(): ScaleArgs = ScaleArgs(
        maxReplicas = maxReplicas,
        minReplicas = minReplicas,
        rules = rules,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/ScaleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.ScaleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Container App scaling configurations.
 * @property maxReplicas Optional. Maximum number of container replicas. Defaults to 10 if not set.
 * @property minReplicas Optional. Minimum number of container replicas.
 * @property rules Scaling rules.
 */
public data class ScaleArgs(
    public val maxReplicas: Output<Int>? = null,
    public val minReplicas: Output<Int>? = null,
    public val rules: Output<List<ScaleRuleArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.ScaleArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.ScaleArgs =
        com.pulumi.azurenative.app.inputs.ScaleArgs.builder()
            .maxReplicas(maxReplicas?.applyValue({ args0 -> args0 }))
            .minReplicas(minReplicas?.applyValue({ args0 -> args0 }))
            .rules(
                rules?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ScaleArgs].
 */
@PulumiTagMarker
public class ScaleArgsBuilder internal constructor() {
    private var maxReplicas: Output<Int>? = null

    private var minReplicas: Output<Int>? = null

    private var rules: Output<List<ScaleRuleArgs>>? = null

    /**
     * @param value Optional. Maximum number of container replicas. Defaults to 10 if not set.
     */
    @JvmName("oxsbplidnqtggsjr")
    public suspend fun maxReplicas(`value`: Output<Int>) {
        this.maxReplicas = value
    }

    /**
     * @param value Optional. Minimum number of container replicas.
     */
    @JvmName("nxlnjpbficigxyie")
    public suspend fun minReplicas(`value`: Output<Int>) {
        this.minReplicas = value
    }

    /**
     * @param value Scaling rules.
     */
    @JvmName("roaajbqeyhbgexie")
    public suspend fun rules(`value`: Output<List<ScaleRuleArgs>>) {
        this.rules = value
    }

    @JvmName("mfyiosvijfxgpeds")
    public suspend fun rules(vararg values: Output<ScaleRuleArgs>) {
        this.rules = Output.all(values.asList())
    }

    /**
     * @param values Scaling rules.
     */
    @JvmName("vtanpnfxddbdxmsv")
    public suspend fun rules(values: List<Output<ScaleRuleArgs>>) {
        this.rules = Output.all(values)
    }

    /**
     * @param value Optional. Maximum number of container replicas. Defaults to 10 if not set.
     */
    @JvmName("myikllmkwfsnaxfk")
    public suspend fun maxReplicas(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.maxReplicas = mapped
    }

    /**
     * @param value Optional. Minimum number of container replicas.
     */
    @JvmName("ofybntxgrrmwmhve")
    public suspend fun minReplicas(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minReplicas = mapped
    }

    /**
     * @param value Scaling rules.
     */
    @JvmName("uopjrnxedcbviptn")
    public suspend fun rules(`value`: List<ScaleRuleArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    /**
     * @param argument Scaling rules.
     */
    @JvmName("sfhakwwqydkonhkh")
    public suspend fun rules(argument: List<suspend ScaleRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { ScaleRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument Scaling rules.
     */
    @JvmName("kruwaqimgekumfiu")
    public suspend fun rules(vararg argument: suspend ScaleRuleArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { ScaleRuleArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param argument Scaling rules.
     */
    @JvmName("nvosejkxgjyjgloq")
    public suspend fun rules(argument: suspend ScaleRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ScaleRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.rules = mapped
    }

    /**
     * @param values Scaling rules.
     */
    @JvmName("gjatyaiylifmxmyb")
    public suspend fun rules(vararg values: ScaleRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rules = mapped
    }

    internal fun build(): ScaleArgs = ScaleArgs(
        maxReplicas = maxReplicas,
        minReplicas = minReplicas,
        rules = rules,
    )
}
